pub fn can_new(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
P Defines if
on_new
and
on_pre_new
command handlers are enabled in the widget and descendants.
Sets the CAN_NEW_VAR.
pub fn can_new(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeP Defines if
on_new
and
on_pre_new
command handlers are enabled in the widget and descendants.
Sets the CAN_NEW_VAR.