pub fn can_paste(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
P Defines if
on_paste
and
on_pre_paste
command handlers are enabled in the widget and descendants.
Sets the CAN_PASTE_VAR.
pub fn can_paste(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeP Defines if
on_paste
and
on_pre_paste
command handlers are enabled in the widget and descendants.
Sets the CAN_PASTE_VAR.