pub fn can_save(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
P Defines if
on_save
and
on_pre_save
command handlers are enabled in the widget and descendants.
Sets the CAN_SAVE_VAR.
pub fn can_save(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeP Defines if
on_save
and
on_pre_save
command handlers are enabled in the widget and descendants.
Sets the CAN_SAVE_VAR.