on_cut

Function on_cut 

pub fn on_cut(child: impl IntoUiNode, handler: Handler<CommandArgs>) -> UiNode
P On cut command.

Receives CUT_CMD command events scoped on the widget. You can use the CLIPBOARD service to send data to the clipboard.

Command

This property will subscribe to the CUT_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_cut .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.