pub fn on_pre_save_as(
child: impl IntoUiNode,
handler: Handler<CommandArgs>,
) -> UiNodeExpand description
P On save-as command.
Receives SAVE_AS_CMD command events scoped on the widget. Usually prompts the user for
a new save path.
Command
This property will subscribe to the
SAVE_AS_CMD
command scoped on the widget. If set on the Window! root widget it will also subscribe to
the command scoped on the window.
The command handle is enabled by default and can be disabled using the contextual property
can_save_as
.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.