on_save_as

Function on_save_as 

pub fn on_save_as(
    child: impl IntoUiNode,
    handler: Handler<CommandArgs>,
) -> UiNode
P On save-as command.

Receives SAVE_AS_CMD command events scoped on the widget. Usually prompts the user for a new save path.

Command

This property will subscribe to the SAVE_AS_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_save_as .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.