pub fn on_drag_end(
child: impl IntoUiNode,
handler: Handler<DragEndArgs>,
) -> UiNodeExpand description
P Draggable widget stopped dragging.
This event is always paired with on_drag_start first.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.