pub fn on_drag_start(
child: impl IntoUiNode,
handler: Handler<DragStartArgs>,
) -> UiNodeExpand description
P Draggable widget started dragging.
To receive this event in a widget set draggable to true.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.