on_drop

Function on_drop 

pub fn on_drop(child: impl IntoUiNode, handler: Handler<DropArgs>) -> UiNode
P Dragging cursor dropped data in the widget area and the widget is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.