on_pre_drag_enter

Function on_pre_drag_enter 

pub fn on_pre_drag_enter(
    child: impl IntoUiNode,
    handler: Handler<DragHoveredArgs>,
) -> UiNode
P Dragging cursor entered the widget area and the widget is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.