pub fn on_pre_drag_start( child: impl IntoUiNode, handler: Handler<DragStartArgs>, ) -> UiNode
P Draggable widget started dragging.
P
To receive this event in a widget set draggable to true.
draggable
true
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident