on_blur

Function on_blur 

pub fn on_blur(
    child: impl IntoUiNode,
    handler: Handler<FocusChangedArgs>,
) -> UiNode
P Widget lost direct keyboard focus.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.