on_focus_changed

Function on_focus_changed 

pub fn on_focus_changed(
    child: impl IntoUiNode,
    handler: Handler<FocusChangedArgs>,
) -> UiNode
P Focus changed in the widget or its descendants.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.