on_focus_leave

Function on_focus_leave 

pub fn on_focus_leave(
    child: impl IntoUiNode,
    handler: Handler<FocusChangedArgs>,
) -> UiNode
P Widget or one of its descendants lost focus.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.