on_pre_blur

Function on_pre_blur 

pub fn on_pre_blur(
    child: impl IntoUiNode,
    handler: Handler<FocusChangedArgs>,
) -> UiNode
P Widget lost direct keyboard focus.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.