pub fn on_pre_focus( child: impl IntoUiNode, handler: Handler<FocusChangedArgs>, ) -> UiNode
P Widget got direct keyboard focus.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident