on_pre_focus_changed

Function on_pre_focus_changed 

pub fn on_pre_focus_changed(
    child: impl IntoUiNode,
    handler: Handler<FocusChangedArgs>,
) -> UiNode
P Focus changed in the widget or its descendants.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.