on_pre_focus_leave

Function on_pre_focus_leave 

pub fn on_pre_focus_leave(
    child: impl IntoUiNode,
    handler: Handler<FocusChangedArgs>,
) -> UiNode
P Widget or one of its descendants lost focus.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.