get_mnemonic_char

Function get_mnemonic_char 

pub fn get_mnemonic_char(
    child: impl IntoUiNode,
    state: impl IntoVar<Option<char>>,
) -> UiNode
P Get the active mnemonic shortcut char for this widget or ancestor.

If this widget or ancestor enables mnemonic the state is set to the selected mnemonic char when focus is within the parent mnemonic_scope.