pub fn mnemonic_scope(
child: impl IntoUiNode,
is_scope: impl IntoVar<bool>,
) -> UiNodeExpand description
P Defines a mnemonic shortcut scope.
When focus is within the scope widget and the focus event was caused by key press a
GESTURES.click_shortcut is set for each mnemonic descendant.