on_any_click

Function on_any_click 

pub fn on_any_click(
    child: impl IntoUiNode,
    handler: Handler<ClickArgs>,
) -> UiNode
P On widget click from any source and of any click count and the widget is enabled.

This is the most general click handler, it raises for all possible sources of the CLICK_EVENT and any number of consecutive clicks. Use on_click to handle only primary button clicks or on_any_single_click to not include double/triple clicks.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.