on_any_single_click

Function on_any_single_click 

pub fn on_any_single_click(
    child: impl IntoUiNode,
    handler: Handler<ClickArgs>,
) -> UiNode
P On widget click from any source but excluding double/triple clicks and the widget is enabled.

This raises for all possible sources of CLICK_EVENT, but only when the click count is one. Use on_single_click to handle only primary button clicks.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.