pub fn on_any_triple_click(
child: impl IntoUiNode,
handler: Handler<ClickArgs>,
) -> UiNodeExpand description
P On widget triple click from any source and the widget is enabled.
This raises for all possible sources of CLICK_EVENT, but only when the click count is three. Use
on_triple_click to handle only primary button clicks.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.