pub fn on_disabled_click(
child: impl IntoUiNode,
handler: Handler<ClickArgs>,
) -> UiNodeExpand description
P On widget click from any source and of any click count and the widget is disabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.