pub fn on_pre_any_single_click(
child: impl IntoUiNode,
handler: Handler<ClickArgs>,
) -> UiNodeExpand description
P On widget click from any source but excluding double/triple clicks and the widget is enabled.
This raises for all possible sources of CLICK_EVENT, but only when the click count is one. Use
on_single_click to handle only primary button clicks.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.