on_pre_disabled_click

Function on_pre_disabled_click 

pub fn on_pre_disabled_click(
    child: impl IntoUiNode,
    handler: Handler<ClickArgs>,
) -> UiNode
P On widget click from any source and of any click count and the widget is disabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.