on_disabled_mouse_hovered

Function on_disabled_mouse_hovered 

pub fn on_disabled_mouse_hovered(
    child: impl IntoUiNode,
    handler: Handler<MouseHoverArgs>,
) -> UiNode
P Mouse entered or left the widget and descendant widgets area, the widget is disabled and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.