pub fn on_disabled_mouse_input(
child: impl IntoUiNode,
handler: Handler<MouseInputArgs>,
) -> UiNodeExpand description
P Mouse button pressed or release while the cursor is over the widget, the widget is disabled and no cursor
capture blocks it.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.