pub fn on_mouse_enter(
child: impl IntoUiNode,
handler: Handler<MouseHoverArgs>,
) -> UiNodeExpand description
P Mouse is now over the widget or a descendant widget, the widget is enabled and cursor capture allows it.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.