on_mouse_leave

Function on_mouse_leave 

pub fn on_mouse_leave(
    child: impl IntoUiNode,
    handler: Handler<MouseHoverArgs>,
) -> UiNode
P Mouse is no longer over the widget or any descendant widget, the widget is enabled and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.