on_mouse_scroll

Function on_mouse_scroll 

pub fn on_mouse_scroll(
    child: impl IntoUiNode,
    handler: Handler<MouseWheelArgs>,
) -> UiNode
P Mouse wheel scrolled while pointer is hovering the widget and the pressed keyboard modifiers allow a scroll operation and the widget is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.