pub fn on_mouse_up(
child: impl IntoUiNode,
handler: Handler<MouseInputArgs>,
) -> UiNodeExpand description
P Mouse button released while the cursor if over the widget, the widget is enabled and cursor capture allows it.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.