on_pre_disabled_mouse_click

Function on_pre_disabled_mouse_click 

pub fn on_pre_disabled_mouse_click(
    child: impl IntoUiNode,
    handler: Handler<MouseClickArgs>,
) -> UiNode
P Mouse clicked on the disabled widget with the primary button, including repeat clicks.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.