Function on_pre_disabled_mouse_input
Source pub fn on_pre_disabled_mouse_input(
child: impl IntoUiNode,
handler: Handler<MouseInputArgs>,
) -> UiNode
P Mouse button pressed or release while the cursor is over the widget, the widget is disabled and no cursor
capture blocks it.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.