on_pre_mouse_any_double_click

Function on_pre_mouse_any_double_click 

pub fn on_pre_mouse_any_double_click(
    child: impl IntoUiNode,
    handler: Handler<MouseClickArgs>,
) -> UiNode
P Mouse double clicked on the widget with any button and it is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.