pub fn on_pre_mouse_any_single_click( child: impl IntoUiNode, handler: Handler<MouseClickArgs>, ) -> UiNode
P Mouse clicked on the widget with any button but excluding repeat clicks and it is enabled.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident