Function on_pre_mouse_enter
Source pub fn on_pre_mouse_enter(
child: impl IntoUiNode,
handler: Handler<MouseHoverArgs>,
) -> UiNode
P Mouse is now over the widget or a descendant widget, the widget is enabled and cursor capture allows it.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.