on_pre_mouse_hovered

Function on_pre_mouse_hovered 

pub fn on_pre_mouse_hovered(
    child: impl IntoUiNode,
    handler: Handler<MouseHoverArgs>,
) -> UiNode
P Mouse entered or left the widget and descendant widgets area, the widget is enabled and cursor capture allows it.

You can use the is_mouse_enter and is_mouse_leave methods to determinate the state change.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.