on_pre_mouse_input

Function on_pre_mouse_input 

pub fn on_pre_mouse_input(
    child: impl IntoUiNode,
    handler: Handler<MouseInputArgs>,
) -> UiNode
P Mouse button pressed or released while the cursor is over the widget, the widget is enabled and no cursor capture blocks it.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.