Function on_pre_mouse_up
Source pub fn on_pre_mouse_up(
child: impl IntoUiNode,
handler: Handler<MouseInputArgs>,
) -> UiNode
P Mouse button released while the cursor if over the widget, the widget is enabled and cursor capture allows it.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.