on_pre_mouse_wheel

Function on_pre_mouse_wheel 

pub fn on_pre_mouse_wheel(
    child: impl IntoUiNode,
    handler: Handler<MouseWheelArgs>,
) -> UiNode
P Mouse wheel scrolled while pointer is hovering widget and it is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.