on_lost_pointer_capture

Function on_lost_pointer_capture 

pub fn on_lost_pointer_capture(
    child: impl IntoUiNode,
    handler: Handler<PointerCaptureArgs>,
) -> UiNode
P Widget lost mouse and touch capture.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.