on_pre_lost_pointer_capture

Function on_pre_lost_pointer_capture 

pub fn on_pre_lost_pointer_capture(
    child: impl IntoUiNode,
    handler: Handler<PointerCaptureArgs>,
) -> UiNode
P Widget lost mouse and touch capture.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.