on_pre_pointer_capture_changed

Function on_pre_pointer_capture_changed 

pub fn on_pre_pointer_capture_changed(
    child: impl IntoUiNode,
    handler: Handler<PointerCaptureArgs>,
) -> UiNode
P Widget acquired or lost mouse and touch capture.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.