#[non_exhaustive]pub struct CursorImg {
pub source: ImageSource,
pub hotspot: Point,
pub fallback: CursorIcon,
}Expand description
Window custom cursor.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: ImageSourceCursor image source.
For better compatibility use a square image between 32 and 128 pixels.
hotspot: PointPixel in the source image that is the exact mouse position.
This value is ignored if the image source format already has hotspot information.
fallback: CursorIconIcon to use if the image cannot be displayed.
Implementations
Sourceimpl CursorImg
impl CursorImg
Sourcepub fn new(source: impl Into<ImageSource>, fallback: CursorIcon) -> CursorImg
pub fn new(source: impl Into<ImageSource>, fallback: CursorIcon) -> CursorImg
New with default hotspot.