pub fn on_pre_disabled_touch_input( child: impl IntoUiNode, handler: Handler<TouchInputArgs>, ) -> UiNode
P Touch contact started or ended over the widget, it is disabled and cursor capture allows it.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident