pub fn on_pre_disabled_touch_long_press( child: impl IntoUiNode, handler: Handler<TouchLongPressArgs>, ) -> UiNode
P Single touch contact was made and held in place for a duration of time (default 500ms) on the widget and the widget is disabled.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident