pub fn on_pre_disabled_touch_tap( child: impl IntoUiNode, handler: Handler<TouchTapArgs>, ) -> UiNode
P Touch tap on the widget and it is disabled.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident