on_pre_touch_cancel

Function on_pre_touch_cancel 

pub fn on_pre_touch_cancel(
    child: impl IntoUiNode,
    handler: Handler<TouchInputArgs>,
) -> UiNode
P Touch contact canceled over the widget, it is enabled and cursor capture allows it.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.