on_pre_touch_end

Function on_pre_touch_end 

pub fn on_pre_touch_end(
    child: impl IntoUiNode,
    handler: Handler<TouchInputArgs>,
) -> UiNode
P Touch contact ended over the widget, it is enabled and cursor capture allows it.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.