pub fn on_pre_touch_move( child: impl IntoUiNode, handler: Handler<TouchMoveArgs>, ) -> UiNode
P Touch contact moved over the widget and cursor capture allows it.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident