pub fn on_pre_touch_transform( child: impl IntoUiNode, handler: Handler<TouchTransformArgs>, ) -> UiNode
P Touch gesture to translate, scale or rotate happened over this widget.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident