on_pre_touched

Function on_pre_touched 

pub fn on_pre_touched(
    child: impl IntoUiNode,
    handler: Handler<TouchedArgs>,
) -> UiNode
P Touch contact entered or left the widget and descendants area and it is enabled.

You can use the is_touch_enter and is_touch_leave methods to determinate the state change.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.