on_touch_cancel

Function on_touch_cancel 

pub fn on_touch_cancel(
    child: impl IntoUiNode,
    handler: Handler<TouchInputArgs>,
) -> UiNode
P Touch contact canceled over the widget, it is enabled and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.