on_touch_end

Function on_touch_end 

pub fn on_touch_end(
    child: impl IntoUiNode,
    handler: Handler<TouchInputArgs>,
) -> UiNode
P Touch contact ended over the widget, it is enabled and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.