pub fn on_touch_input(
child: impl IntoUiNode,
handler: Handler<TouchInputArgs>,
) -> UiNodeExpand description
P Touch contact started or ended over the widget, it is enabled and cursor capture allows it.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.