on_touch_move

Function on_touch_move 

pub fn on_touch_move(
    child: impl IntoUiNode,
    handler: Handler<TouchMoveArgs>,
) -> UiNode
P Touch contact moved over the widget and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.