pub fn on_pre_drag_end(
child: impl IntoUiNode,
handler: Handler<DragEndArgs>,
) -> UiNodeExpand description
P Draggable widget stopped dragging.
This event is always paired with on_drag_start first.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.