pub fn get_mnemonic(
child: impl IntoUiNode,
state: impl IntoVar<Mnemonic>,
) -> UiNodeExpand description
P Gets the mnemonic mode enabled for this widget or ancestor.
If this widget or ancestor enables mnemonic the state is set to the mnemonic mode.