pub fn get_mnemonic_char(
child: impl IntoUiNode,
state: impl IntoVar<Option<char>>,
) -> UiNodeExpand description
P Get the active mnemonic shortcut char for this widget or ancestor.
If this widget or ancestor enables mnemonic the state is set to the selected mnemonic char when focus is within
the parent mnemonic_scope.