on_double_click

Function on_double_click 

pub fn on_double_click(
    child: impl IntoUiNode,
    handler: Handler<ClickArgs>,
) -> UiNode
P On widget double click with the primary button and the widget is enabled.

This raises only if the click is primary and the click count is two. Use on_any_double_click to handle double clicks from any button.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.