pub fn on_disabled_mouse_any_click(
child: impl IntoUiNode,
handler: Handler<MouseClickArgs>,
) -> UiNodeExpand description
P Mouse clicked on the disabled widget with any button, including repeat clicks.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.