pub fn on_mouse_single_click(
child: impl IntoUiNode,
handler: Handler<MouseClickArgs>,
) -> UiNodeExpand description
P Mouse clicked on the widget with the primary button excluding repeat clicks and it is enabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.