on_mouse_wheel

Function on_mouse_wheel 

pub fn on_mouse_wheel(
    child: impl IntoUiNode,
    handler: Handler<MouseWheelArgs>,
) -> UiNode
P Mouse wheel scrolled while pointer is hovering widget and it is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.