pub fn on_pre_disabled_mouse_hovered( child: impl IntoUiNode, handler: Handler<MouseHoverArgs>, ) -> UiNode
P Mouse entered or left the widget and descendant widgets area, the widget is disabled and cursor capture allows it.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident