on_pre_mouse_move

Function on_pre_mouse_move 

pub fn on_pre_mouse_move(
    child: impl IntoUiNode,
    handler: Handler<MouseMoveArgs>,
) -> UiNode
P Mouse cursor moved over the widget and cursor capture allows it.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.