pub fn on_lost_pointer_capture(
child: impl IntoUiNode,
handler: Handler<PointerCaptureArgs>,
) -> UiNodeExpand description
P Widget lost mouse and touch capture.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.