on_pre_touch_enter

Function on_pre_touch_enter 

pub fn on_pre_touch_enter(
    child: impl IntoUiNode,
    handler: Handler<TouchedArgs>,
) -> UiNode
P Touch contact is now over the widget or a descendant and it is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.