pub fn on_pre_touch_enter( child: impl IntoUiNode, handler: Handler<TouchedArgs>, ) -> UiNode
P Touch contact is now over the widget or a descendant and it is enabled.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident