pub fn on_touch_leave(
child: impl IntoUiNode,
handler: Handler<TouchedArgs>,
) -> UiNodeExpand description
P Touch contact is no longer over the widget or any descendant and it is enabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.