pub fn on_touch_transform(
child: impl IntoUiNode,
handler: Handler<TouchTransformArgs>,
) -> UiNodeExpand description
P Touch gesture to translate, scale or rotate happened over this widget.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.